@@ -1,5 +1,5 @@
 from tunas2dsdl.generator.generate import Generation
-from tunas2dsdl.parser import DetectionParse, SemanticSegmentationParse
+from tunas2dsdl.parser import DetectionParse, SemanticSegmentationParse, KeyPoint2DParse
 from .general.classdomain import ClassDomain, Label
 from .general.struct import Struct, Field
 from .general import OptionEatAll
@@ -8,6 +8,8 @@ from .__version__ import __version__
 __all__ = [
     "Generation",
     "DetectionParse",
+    "SemanticSegmentationParse",
+    "KeyPoint2DParse",
     "ClassDomain",
     "Label",
     "Struct",
